==> tuweni-src-2.0.0-incubating.tgz: tuweni-src-2.0.0/rlpx/src/main/java/org/apache/tuweni/rlpx/wire/Capability.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements. See the NOTICE
 * file distributed with this work for additional information regarding copyright ownership. The ASF licenses this file
 * to You under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.apache.tuweni.rlpx.wire;

import java.util.Objects;

public final class Capability {

  private final String name;

  private final int version;


  Capability(String name, int version) {
    this.name = name;
    this.version = version;
  }

  public String name() {
    return name;
  }

  public int version() {
    return version;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o)
      return true;
    if (o == null || getClass() != o.getClass())
      return false;
    Capability that = (Capability) o;
    return Objects.equals(name, that.name) && Objects.equals(version, that.version);
  }

  @Override
  public int hashCode() {
    return Objects.hash(name, version);
  }

  @Override
  public String toString() {
    return "Capability{" + "name='" + name + '\'' + ", version='" + version + '\'' + '}';
  }
}

==> tuweni-src-2.3.1-incubating.tgz: tuweni-src-2.3.1/rlpx/src/main/java/org/apache/tuweni/rlpx/wire/Capability.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements. See the NOTICE
 * file distributed with this work for additional information regarding copyright ownership. The ASF licenses this file
 * to You under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.apache.tuweni.rlpx.wire;

import java.util.Objects;

public final class Capability {

  private final String name;

  private final int version;


  Capability(String name, int version) {
    this.name = name;
    this.version = version;
  }

  public String name() {
    return name;
  }

  public int version() {
    return version;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o)
      return true;
    if (o == null || getClass() != o.getClass())
      return false;
    Capability that = (Capability) o;
    return Objects.equals(name, that.name) && version == that.version;
  }

  @Override
  public int hashCode() {
    return Objects.hash(name, version);
  }

  @Override
  public String toString() {
    return "Capability{" + "name='" + name + '\'' + ", version='" + version + '\'' + '}';
  }
}
